Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(131)

Unified Diff: mojo/shell/public/cpp/lib/connection_impl.cc

Issue 1686223002: Move InterfaceProvider into the shell::mojom namespace like the rest of the shell interfaces. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/shell/public/cpp/lib/connection_impl.h ('k') | mojo/shell/public/cpp/lib/shell_connection.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/shell/public/cpp/lib/connection_impl.cc
diff --git a/mojo/shell/public/cpp/lib/connection_impl.cc b/mojo/shell/public/cpp/lib/connection_impl.cc
index 447ace68f0d9ee20deb0ca9d468bdde42f0dd213..bc66e70ecc60b0406357c34c4dfe7abc72229c1d 100644
--- a/mojo/shell/public/cpp/lib/connection_impl.cc
+++ b/mojo/shell/public/cpp/lib/connection_impl.cc
@@ -23,8 +23,8 @@ ConnectionImpl::ConnectionImpl(
const std::string& connection_url,
const std::string& remote_url,
uint32_t remote_id,
- InterfaceProviderPtr remote_interfaces,
- InterfaceRequest<InterfaceProvider> local_interfaces,
+ shell::mojom::InterfaceProviderPtr remote_interfaces,
+ shell::mojom::InterfaceProviderRequest local_interfaces,
const std::set<std::string>& allowed_interfaces)
: connection_url_(connection_url),
remote_url_(remote_url),
@@ -94,11 +94,11 @@ const std::string& ConnectionImpl::GetRemoteApplicationURL() {
return remote_url_;
}
-InterfaceProvider* ConnectionImpl::GetRemoteInterfaces() {
+shell::mojom::InterfaceProvider* ConnectionImpl::GetRemoteInterfaces() {
return remote_interfaces_.get();
}
-InterfaceProvider* ConnectionImpl::GetLocalInterfaces() {
+shell::mojom::InterfaceProvider* ConnectionImpl::GetLocalInterfaces() {
return this;
}
@@ -137,7 +137,7 @@ base::WeakPtr<Connection> ConnectionImpl::GetWeakPtr() {
}
////////////////////////////////////////////////////////////////////////////////
// ConnectionImpl, InterfaceProvider implementation:
void ConnectionImpl::GetInterface(const mojo::String& interface_name,
ScopedMessagePipeHandle handle) {
« no previous file with comments | « mojo/shell/public/cpp/lib/connection_impl.h ('k') | mojo/shell/public/cpp/lib/shell_connection.cc » ('j') | no next file with comments »
@@ -137,7 +137,7 @@ base::WeakPtr<Connection> ConnectionImpl::GetWeakPtr() {
}
////////////////////////////////////////////////////////////////////////////////
-// ConnectionImpl, InterfaceProvider implementation:
+// ConnectionImpl, shell::mojom::InterfaceProvider implementation:
void ConnectionImpl::GetInterface(const mojo::String& interface_name,
ScopedMessagePipeHandle handle) {

Powered by Google App Engine
This is Rietveld 408576698